import { injectReportDialog, SDK_NAME, SDK_VERSION } from '@sentry/browser';
import { BaseClient, getCurrentHub } from '@sentry/core';
import { logger } from '@sentry/utils';
import { RendererBackend } from './backend';
/** Frontend implementation for Electron renderer backends. */
export class RendererClient extends BaseClient {
    /**
     * Creates a new Electron SDK instance.
     * @param options Configuration options for this SDK.
     */
    constructor(options) {
        super(RendererBackend, options);
    }
    /**
     * @inheritDoc
     */
    _prepareEvent(event, scope, hint) {
        event.platform = event.platform || 'javascript';
        event.sdk = Object.assign(Object.assign({}, event.sdk), { name: SDK_NAME, packages: [
                ...((event.sdk && event.sdk.packages) || []),
                {
                    name: 'npm:@sentry/browser',
                    version: SDK_VERSION,
                },
            ], version: SDK_VERSION });
        return super._prepareEvent(event, scope, hint);
    }
    /**
     * Uploads a native crash dump (Minidump) to Sentry.
     *
     * @param path The relative or absolute path to the minidump.
     * @param event Optional event payload to attach to the minidump.
     * @param scope The SDK scope used to upload.
     */
    captureMinidump() {
        logger.warn('captureMinidump is a noop on the renderer');
        return undefined;
    }
    /**
     * Basically calling {@link BrowserClient.showReportDialog}
     * @inheritdoc
     */
    showReportDialog(options = {}) {
        if (!options.eventId) {
            options.eventId = getCurrentHub().lastEventId();
        }
        injectReportDialog(options);
    }
}
//# sourceMappingURL=client.js.map